@@ -14,7 +14,7 @@ BEGIN{
 		$HUF = 'Hash::Util::FieldHash::Compat';
 	}
 
-	$HUF->import(qw(fieldhash id));
+	$HUF->import(qw(fieldhash));
 }
 
 printf "Perl %vd on $^O\n", $^V;
